.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. index:: Courses
.. _chap_courses:

**************
PyMVPA Courses
**************

:ref:`chap_tutorial` provides a collection of materials which could either be
used for learning PyMVPA independently, or for teaching PyMVPA in workshops.
This page provides a collection of programs, slides, and tutorials used in the
past PyMVPA courses.

Justus-Liebig-Universitat, Giessen Germany, September 19-20, 2014
-----------------------------------------------------------------

Day 1
  - `Administrative remarks <http://www.pymvpa.org/files/_talks/giessen-2014/s-admin.pdf>`__
  - Lecture ”`A very short introduction to multivariate pattern analysis (MVPA)
    for neuroscience <http://www.pymvpa.org/files/_talks/giessen-2014/s-mvpaintro.pdf>`__”
  - Quiz: ”`Python foundations <http://www.pymvpa.org/files/_talks/giessen-2014/s-prereq.pdf>`__”
  - Hands-on “:ref:`Data representation in PyMVPA <chap_tutorial_datasets>`”
  - Hands-on “:ref:`PyMVPA building blocks <chap_tutorial_mappers>`
    and :ref:`the command line interface <example_cmdline_fmri_analyses>`”
  - Lecture ”`Basic MVPA strategies <http://www.pymvpa.org/files/_talks/giessen-2014/s-mvpastrategies.pdf>`__”
  - Hands-on “:ref:`Classification and cross-validation <chap_tutorial_classifiers>`“
  - Hands-on “:ref:`Meta-classifiers <chap_tutorial_meta_classifiers>` and :ref:`Searchlights <chap_tutorial_searchlight>`“
Day 2
  - Lecture “`Advanced methods, other data modalities and current developments <http://www.pymvpa.org/files/_talks/giessen-2014/s-advancedmethods.pdf>`_”
  - Hands-on “:ref:`Searchlights (revamped) <chap_tutorial_searchlight>` and :ref:`RSA <example_rsa_fmri>`”
  - Hands-on “:ref:`Feature extraction and preprocessing <chap_tutorial_eventrelated>`”
  - Lecture “`PyMVPA and the larger scientific software eco-system <http://www.pymvpa.org/files/_talks/giessen-2014/s-pymvpaecosystem.pdf>`__”
  - Hands-on “:ref:`Group analyses <example_hyperalignment>`”
  - Hands-on “:ref:`Statistical evaluation <chap_tutorial_significance>` and Q&A”


Hanse-Wissenschaftskolleg, Germany, March 6-7, 2014
---------------------------------------------------

Day 1
  - `Administrative remarks <http://www.pymvpa.org/files/_talks/hwk-2014/s-admin.pdf>`__
  - Lecture ”`A very short introduction to multivariate pattern analysis (MVPA)
    for neuroscience <http://www.pymvpa.org/files/_talks/hwk-2014/s-mvpaintro.pdf>`__”
  - Quiz: ”`Python foundations <http://www.pymvpa.org/files/_talks/hwk-2014/s-prereq.pdf>`__”
  - Hands-on “:ref:`Data representation in PyMVPA <chap_tutorial_datasets>`”
  - Hands-on “:ref:`PyMVPA building blocks <chap_tutorial_mappers>`
    and :ref:`the command line interface <example_cmdline_fmri_analyses>`”
  - Lecture ”`Basic MVPA strategies <http://www.pymvpa.org/files/_talks/hwk-2014/s-mvpastrategies.pdf>`__”
  - Hands-on “:ref:`Classification and cross-validation <chap_tutorial_classifiers>`“
  - Hands-on “:ref:`Searchlights <chap_tutorial_searchlight>`“
Day 2
  - Lecture “`PyMVPA and the larger scientific software eco-system <http://www.pymvpa.org/files/_talks/hwk-2014/s-pymvpaecosystem.pdf>`__”
  - Hands-on “:ref:`Feature extraction and preprocessing <chap_tutorial_eventrelated>`”
  - Hands-on “:ref:`Connecting building blocks into analysis workflows <chap_tutorial_meta_classifiers>`”
  - Lecture “`Advanced methods, other data modalities and current developments <http://www.pymvpa.org/files/_talks/hwk-2014/s-advancedmethods.pdf>`_”
  - Hands-on “:ref:`Group analyses <example_hyperalignment>`”
  - Hands-on “:ref:`Statistical evaluation <chap_tutorial_significance>`”

University of Magdeburg, Germany, 2012
--------------------------------------

Dartmouth College, USA, 2010
----------------------------
